@@ -6,13 +6,13 @@
 
 '''A simple Twitter client made with pyqt4'''
 
-__version__ = '0.1.9'
+__version__ = '0.1.12'
 
 #TODOS :
 #* Fix Identi.ca oauth bug
-#* Implements Twitpic
+#* Add separate notification for dm and mention
+#* Add list features
 #* Push 0.1.x line to extras
-#* Refactoring, Clean and Comment the code
 #* Add retry on network errors
 
 from utils import *
@@ -59,8 +59,12 @@ if not USE_PYSIDE:
                             QSizePolicy, \
                             QVBoxLayout, \
                             QHBoxLayout, \
-                            QInputDialog
-                                                          
+                            QInputDialog, \
+                            QFileDialog, \
+                            QDirModel                            
+                            
+                            
+#    from PyQt4.QtGui import *                                                      
     from PyQt4.QtCore import QTimer, QSettings, \
                              QUrl, \
                              Qt, QObject
@@ -91,7 +95,8 @@ else:
                              QSizePolicy, \
                              QVBoxLayout, \
                              QHBoxLayout, \
-                             QInputDialog
+                             QInputDialog, \
+                             QFileDialog
                              
     try:
         from QtMobility.Location import * #PySide
@@ -129,7 +134,7 @@ class KhweeteurAbout(QMainWindow):
             aboutScrollArea = QScrollArea(self)
             aboutScrollArea.setWidgetResizable(True)
             awidget = QWidget(aboutScrollArea)
-            awidget.setMinimumSize(480, 1300)
+            awidget.setMinimumSize(480, 1400)
             awidget.setSizePolicy(QSizePolicy.Expanding,
                                   QSizePolicy.Expanding)
             aboutScrollArea.setSizePolicy(QSizePolicy.Expanding,
@@ -187,6 +192,8 @@ class KhweeteurAbout(QMainWindow):
                                    <br>teotwaki on twitter
                                    <br>Jaffa on maemo.org
                                    <br>creip on Twitter
+                                   <br>zcopley on #statusnet
+                                   <br>jordan_c on #statusnet
                                    </center>''')
                    % __version__)
         aboutLayout.addWidget(aboutLabel)
@@ -276,16 +283,17 @@ class KhweeteurWin(QMainWindow):
 
         self.search_win = []
 
-        self.settings = QSettings()
+        self.settings = KhweeteurSettings()
 
         #Crappy fix for old prefs due to change to QVariant
         #Api 2 and PySide
-        if self.settings.value('twitter_access_token') in ('True','1'):
+        if self.settings.value('twitter_access_token') in ('True','1',1):
             self.settings.setValue('twitter_access_token',1)
         else:
+            print 'Should not happen error 448:',type(self.settings.value('twitter_access_token')),self.settings.value('twitter_access_token')
             self.settings.setValue('twitter_access_token',0)
             
-        if self.settings.value('identica_access_token') in ('True','1'):
+        if self.settings.value('identica_access_token') in ('True','1',1):
             self.settings.setValue('identica_access_token',1)
         else:
             self.settings.setValue('identica_access_token',0)
@@ -597,14 +605,14 @@ class KhweeteurWin(QMainWindow):
                                         ) % (user_screenname, str(e)))
                                 print e
 
-                    if 'http://identi.ca/api/' \
+                    if 'http://identi.ca/api' \
                         == self.tweetsModel.data(index,
                             role=ORIGINROLE):
                         try:
                             if self.settings.value('identica_access_token_key'
                                     ) != None:
                                 api = \
-                                    twitter.Api(base_url='http://identi.ca/api/'
+                                    twitter.Api(base_url='http://identi.ca/api'
                                         ,
                                         username=KHWEETEUR_IDENTICA_CONSUMER_KEY,
                                         password=KHWEETEUR_IDENTICA_CONSUMER_SECRET,
@@ -683,14 +691,14 @@ class KhweeteurWin(QMainWindow):
                                         ) % (user_screenname, str(e)))
                                 print e
 
-                    if 'http://identi.ca/api/' \
+                    if 'http://identi.ca/api' \
                         == self.tweetsModel.data(index,
                             role=ORIGINROLE):
                         try:
                             if self.settings.value('identica_access_token_key'
                                     ) != None:
                                 api = \
-                                    twitter.Api(base_url='http://identi.ca/api/'
+                                    twitter.Api(base_url='http://identi.ca/api'
                                         ,
                                         username=KHWEETEUR_IDENTICA_CONSUMER_KEY,
                                         password=KHWEETEUR_IDENTICA_CONSUMER_SECRET,
@@ -764,13 +772,13 @@ class KhweeteurWin(QMainWindow):
                                     ) + str(e))
                             print e
 
-                if 'http://identi.ca/api/' \
+                if 'http://identi.ca/api' \
                     == self.tweetsModel.data(index, role=ORIGINROLE):
                     try:
                         if self.settings.value('identica_access_token_key'
                                 ) != None:
                             api = \
-                                twitter.Api(base_url='http://identi.ca/api/'
+                                twitter.Api(base_url='http://identi.ca/api'
                                     ,
                                     username=KHWEETEUR_IDENTICA_CONSUMER_KEY,
                                     password=KHWEETEUR_IDENTICA_CONSUMER_SECRET,
@@ -845,13 +853,13 @@ class KhweeteurWin(QMainWindow):
                                      + str(e))
                             print e
 
-                if 'http://identi.ca/api/' \
+                if 'http://identi.ca/api' \
                     == self.tweetsModel.data(index, role=ORIGINROLE):
                     try:
                         if self.settings.value('identica_access_token_key'
                                 ) != None:
                             api = \
-                                twitter.Api(base_url='http://identi.ca/api/'
+                                twitter.Api(base_url='http://identi.ca/api'
                                     ,
                                     username=KHWEETEUR_IDENTICA_CONSUMER_KEY,
                                     password=KHWEETEUR_IDENTICA_CONSUMER_SECRET,
@@ -1028,8 +1036,8 @@ class KhweeteurWin(QMainWindow):
         fileMenu.addAction(self.tr('&Search'), self.open_search,
                            QKeySequence(self.tr('Ctrl+S', 'Search')))
 
-#        fileMenu.addAction(self.tr('&TwitPic Upload'), self.twitpic_upload,
-#                           QKeySequence(self.tr('Ctrl+T', 'Twitpic Upload')))
+        fileMenu.addAction(self.tr('&TwitPic Upload'), self.twitpic_pre_upload,
+                           QKeySequence(self.tr('Ctrl+T', 'Twitpic Upload')))
 
         if self.search_keyword != None:
             keywords = self.settings.value('savedSearch')
@@ -1046,29 +1054,43 @@ class KhweeteurWin(QMainWindow):
 
         fileMenu.addAction(self.tr('&About'), self.do_about)
 
-#    def twitpic_upload(self):
-#        message = 'Test'
-#        import twitpic2
-#        api = \
-#            twitter.Api(username=KHWEETEUR_TWITTER_CONSUMER_KEY,
-#                password=KHWEETEUR_TWITTER_CONSUMER_SECRET,
-#                access_token_key=str(self.settings.value('twitter_access_token_key'
-#                )),
-#                access_token_secret=str(self.settings.value('twitter_access_token_secret'
-#                )))
-#        twitpic = twitpic2.TwitPicOAuthClient(
-#            consumer_key = KHWEETEUR_TWITTER_CONSUMER_KEY,
-#            consumer_secret = KHWEETEUR_TWITTER_CONSUMER_SECRET,
-#            access_token = ACCESS_TOKEN, #FIXME
-#            service_key = 'f9b7357e0dc5473df5f141145e4dceb0'
-#            )
-#        # methods - read, create, update, remove
-#        params = []
-#        params['media'] = 'khweeteur.png'
-#        params['message'] = 'Test of python-twitpic module from #Khweeteur'
-#        response = twitpic2.create('upload', params)
-#        print response
+    @pyqtSlot()
+    def twitpic_pre_upload(self):
+        filename =  QFileDialog.getOpenFileName(self,
+                            "Khweeteur",'/home/user/MyDocs')
 
+        twitpic_message, ok = QInputDialog.getText(self, self.tr('Twitpic Message'), self.tr('Enter the twitpic message :'))
+
+        if ((not (filename == '')) and ok) :
+            try:
+                if not self.nw.device_has_networking:
+                    self.nw.request_connection_with_tmp_callback(lambda data=((filename,twitpic_message),None,None,None,None):self.twitpic_upload(data))
+                else:
+                    raise StandardError('No network control')
+            except:
+                self.twitpic_upload(((filename,twitpic_message),None,None,None,None))
+
+    @pyqtSlot(unicode)
+    def twitpic_post_upload(self,url):
+        self.tb_text.insertPlainText(url)
+        
+    @pyqtSlot(tuple)
+    def twitpic_upload(self,data):
+        self.tb_text.setDisabled(True)
+        self.tb_tweet.setDisabled(True)
+        self.tweetAction = KhweeteurActionWorker(
+            self,
+            'twitpic',
+            data,
+            )
+        self.tweetAction.info.connect(self.notifications.info)
+        self.tweetAction.warn.connect(self.notifications.warn)
+        self.tweetAction.pictUploaded.connect(self.twitpic_post_upload)
+        self.tweetAction.finished.connect(self.tweetSentFinished)
+        self.tweetAction.start()
+
+
+    @pyqtSlot()
     def del_search(self):
         keywords = self.settings.value('savedSearch')
         if not keywords:
@@ -1085,6 +1107,7 @@ class KhweeteurWin(QMainWindow):
         self.settings.setValue('savedSearch', keywords)
         self.close()
 
+    @pyqtSlot()
     def save_search(self):
         keywords = self.settings.value('savedSearch')
         if not keywords:
