@@ -53,7 +53,23 @@ class KhweetsModel(QAbstractListModel):
     def setLimit(self, limit):
         self.khweets_limit = limit
 
-
+    def getCacheFolder(self):
+        if not hasattr(self,'folder_path'):
+            if self.keyword != None:
+                self.folder_path = os.path.join(CACHE_PATH,
+                        os.path.normcase(unicode(self.keyword.replace('/',
+                        '_'))).encode('UTF-8'))                        
+            else:
+                self.folder_path = TIMELINE_PATH
+    
+            if not os.path.isdir(self.folder_path):
+                try:
+                    os.makedirs(self.folder_path)
+                except IOError, e:
+                    print 'getCacheFolder:', e
+    
+        return self.folder_path
+        
     def orderLimitAndCacheUids(self):
         self._items.sort()
         self._items.reverse()
@@ -114,6 +130,7 @@ class KhweetsModel(QAbstractListModel):
                     item[7],
                     item[8],
                     item[9],
+                    item[10],
                     )
             except StandardError, e:
                 print e
@@ -124,13 +141,14 @@ class KhweetsModel(QAbstractListModel):
                               
     def addStatuses(self, uids):
         #Optimization
+        folder_path = self.getCacheFolder()
         _appendStatusInList = self._appendStatusInList
         pickleload = pickle.load
         try:
             keys = []
             for uid in uids:
                 try:
-                    pkl_file = open(os.path.join(TIMELINE_PATH,
+                    pkl_file = open(os.path.join(folder_path,
                                     str(uid)), 'rb')
                     status = pickleload(pkl_file)
                     pkl_file.close()
@@ -139,13 +157,19 @@ class KhweetsModel(QAbstractListModel):
                     if _appendStatusInList(status):
                         keys.append(status.id)
 
-                except IOError, e:
+                except StandardError, e:
                     print e
-        except StandardError, e:
+                    try:
+                        os.remove(os.path.join(os.path.join(folder_path,
+                                            str(uid)), uid))
+                    except:
+                        pass
 
+        except StandardError, e:
             print "We shouldn't got this error here :", e
             import traceback
             traceback.print_exc()
+            
 
         if len(keys) > 0:
             self.orderLimitAndCacheUids()
@@ -216,6 +240,16 @@ class KhweetsModel(QAbstractListModel):
         if not hasattr(status, 'in_reply_to_status_text'):
             status.in_reply_to_status_text = None
 
+        if hasattr(status, 'retweeted_status'):
+            if status.retweeted_status != None: #Fix truncated RT
+                status.text = status.retweeted_status.text
+                retweet_of = ' : Retweet of ' + status.retweeted_status.user.screen_name
+            else:
+                retweet_of = None
+        else:
+            retweet_of = None
+
+
         # Created_at, Status.id, ScreenName, Text, Rel_Created_at, Profile Image, Reply_ID, Reply_ScreenName, Reply_Text, Origin
 
         self._items.append((  # 0
@@ -228,6 +262,7 @@ class KhweetsModel(QAbstractListModel):
                               # 7
                               # 8
                               # 9
+                              # 10
             status.created_at_in_seconds,
             status.id,
             screen_name,
@@ -238,6 +273,7 @@ class KhweetsModel(QAbstractListModel):
             status.in_reply_to_screen_name,
             status.in_reply_to_status_text,
             status.origin,
+            retweet_of,
             ))
 
         self._uids.append(status.id)
@@ -305,6 +341,7 @@ class KhweetsModel(QAbstractListModel):
         # 7 -> Reply_ScreenName,
         # 8 -> Reply_Text
         # 9 -> Origine
+        # 10 -> Retweet of
 
         if role == Qt.DisplayRole:
             return self._items[index.row()][3]
@@ -320,7 +357,9 @@ class KhweetsModel(QAbstractListModel):
             return self._items[index.row()][8]
         elif role == ORIGINROLE:
             return self._items[index.row()][9]
-        elif role == Qt.ToolTipRole:
+        elif role == RETWEETOFROLE:
+            return self._items[index.row()][10]
+        elif role == TIMESTAMPROLE:
             return self._items[index.row()][4]
         elif role == Qt.DecorationRole:
             try:
